Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5708)

Unified Diff: chrome/browser/ui/webui/options/browser_options_handler.cc

Issue 2215993002: Allow changing metrics reporting state without callback. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix func name Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/session_crashed_bubble_view.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/webui/options/browser_options_handler.cc
diff --git a/chrome/browser/ui/webui/options/browser_options_handler.cc b/chrome/browser/ui/webui/options/browser_options_handler.cc
index 91f9c066b7730d0d0b561626d45dd8ab2f7b619d..058d3441eb7a60457c5bb7624c075187fe73f837 100644
--- a/chrome/browser/ui/webui/options/browser_options_handler.cc
+++ b/chrome/browser/ui/webui/options/browser_options_handler.cc
@@ -2159,17 +2159,17 @@ void BrowserOptionsHandler::HandleMetricsReportingChange(
}
// For Chrome OS updating device settings will notify an observer to update
// metrics pref, however we still need to call |InitiateMetricsReportingChange|
// with a proper callback so that UI gets updated in case of failure to update
// the metrics pref.
// TODO(gayane): Don't call |InitiateMetricsReportingChange| twice so that
// metrics service pref changes only as a result of device settings change for
// Chrome OS .crbug.com/552550.
#if defined(OS_CHROMEOS)
chromeos::CrosSettings::Get()->SetBoolean(chromeos::kStatsReportingPref,
enable);
#endif // defined(OS_CHROMEOS)
- InitiateMetricsReportingChange(
+ ChangeMetricsReportingStateWithReply(
enable,
base::Bind(&BrowserOptionsHandler::NotifyUIOfMetricsReportingChange,
weak_ptr_factory_.GetWeakPtr()));
@@ -2159,17 +2159,17 @@ void BrowserOptionsHandler::HandleMetricsReportingChange(
}
// For Chrome OS updating device settings will notify an observer to update
-// metrics pref, however we still need to call |InitiateMetricsReportingChange|
-// with a proper callback so that UI gets updated in case of failure to update
-// the metrics pref.
-// TODO(gayane): Don't call |InitiateMetricsReportingChange| twice so that
+// metrics pref, however we still need to call
+// |ChangeMetricsReportingStateWithReply| with a proper callback so that UI gets
+// updated in case of failure to update the metrics pref.
+// TODO(gayane): Don't call |ChangeMetricsReportingStateWithReply| twice so that
// metrics service pref changes only as a result of device settings change for
// Chrome OS .crbug.com/552550.
« no previous file with comments | « chrome/browser/ui/views/session_crashed_bubble_view.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698